@@ -280,7 +280,7 @@ public class v0_8_X_Changes {
 				"The new hero select features a minimal UI that retains all the old functionality while trying to keep out of the way as much as possible. The centerpiece of hero select is now the heroes themselves, who are depicted with _new detailed splash arts_ by Aleksandar Komitov! _Make sure check out their credits listing in the new about page!_"));
 
 		changes.addButton( new ChangeButton(Icons.get(Icons.AUDIO), "Sound Effects",
-				"_15+ new sound effects_ have been added to the game, courtesy of Charlie! _Make sure check out their credits listing in the new about page!_\n\n" +
+				"_15+ new sound effects_ have been added to the game, courtesy of Celesti! _Make sure check out their credits listing in the new about page!_\n\n" +
 				"These sounds cover movement, combat, and a bunch of miscellanious situations:\n" +
 				"_-_ Grass now crunches underfoot (extra loud if it's tall grass), and solid floors now have a more solid sound.\n" +
 				"_-_ The default hitsound has been remastered, and weapons can now produce slashing, stabbing, or crushing sounds.\n" +
